==> tuia-advert-center-api-2.4.49-sources.jar: cn/com/duiba/tuia/core/api/dto/LandAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

public class LandAuditDataDto {

    /**
     * 广告计划id
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 审核的账号id
     */
    private Long accountId;
    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 代理商id
     */
    private Long agentId;

    /**
     * 代理商名称
     */
    private String agentName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;
    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 落地页地址
     */
    private String promoteUrl;

    /**
     * 审核动作状态
     */
    private Integer checkType;

    /**
     * 审核人.
     */
    private String reviewer;

    /**
     * 拒绝或冻结理由
     */
    private String reason;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }
}

==> tuia-advert-center-api-2.4.70-sources.jar: cn/com/duiba/tuia/core/api/dto/LandAuditDataDto.java <==
package cn.com.duiba.tuia.core.api.dto;

public class LandAuditDataDto {

    /**
     * 广告计划id
     */
    private Long advertId;

    /**
     * 广告名称
     */
    private String advertName;

    /**
     * 审核的账号id
     */
    private Long accountId;
    /**
     * 广告主名称
     */
    private String accountName;

    /**
     * 代理商id
     */
    private Long agentId;

    /**
     * 代理商名称
     */
    private String agentName;

    /**
     * 一级代理商id
     */
    private Long levelOneAgentId;
    /**
     * 一级代理商名称
     */
    private String levelOneAgentName;

    /**
     * ae id
     */
    private Long aeId;
    private String aeName;
    private Long sellId;
    private String sellName;

    /**
     * 落地页地址
     */
    private String promoteUrl;

    /**
     * 审核动作状态
     */
    private Integer checkType;

    /**
     * 审核人.
     */
    private String reviewer;

    /**
     * 拒绝或冻结理由
     */
    private String reason;

    /**
     * 进审时间
     */
    private String enterCheckTime;
    /**
     * 审核时间
     */
    private String checkTime;
    /**
     * 审核时长
     */
    private Long checkCostTime;

    /**
     * 落地页ID
     */
    private Long landPageId;

    /**
     * 落地页类型：0:测试落地页；1:新媒体落地页；2:配置落地页；4:素材绑定落地页
     */
    private Integer urlType;

    /**
     * 截图url
     */
    private String imageUrl;

    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public String getAdvertName() {
        return advertName;
    }

    public void setAdvertName(String advertName) {
        this.advertName = advertName;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public String getAccountName() {
        return accountName;
    }

    public void setAccountName(String accountName) {
        this.accountName = accountName;
    }

    public Long getAgentId() {
        return agentId;
    }

    public void setAgentId(Long agentId) {
        this.agentId = agentId;
    }

    public String getAgentName() {
        return agentName;
    }

    public void setAgentName(String agentName) {
        this.agentName = agentName;
    }

    public Long getAeId() {
        return aeId;
    }

    public void setAeId(Long aeId) {
        this.aeId = aeId;
    }

    public String getAeName() {
        return aeName;
    }

    public void setAeName(String aeName) {
        this.aeName = aeName;
    }

    public Long getSellId() {
        return sellId;
    }

    public void setSellId(Long sellId) {
        this.sellId = sellId;
    }

    public String getSellName() {
        return sellName;
    }

    public void setSellName(String sellName) {
        this.sellName = sellName;
    }

    public String getPromoteUrl() {
        return promoteUrl;
    }

    public void setPromoteUrl(String promoteUrl) {
        this.promoteUrl = promoteUrl;
    }

    public Integer getCheckType() {
        return checkType;
    }

    public void setCheckType(Integer checkType) {
        this.checkType = checkType;
    }

    public String getReviewer() {
        return reviewer;
    }

    public void setReviewer(String reviewer) {
        this.reviewer = reviewer;
    }

    public String getReason() {
        return reason;
    }

    public void setReason(String reason) {
        this.reason = reason;
    }

    public String getEnterCheckTime() {
        return enterCheckTime;
    }

    public void setEnterCheckTime(String enterCheckTime) {
        this.enterCheckTime = enterCheckTime;
    }

    public String getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(String checkTime) {
        this.checkTime = checkTime;
    }

    public Long getCheckCostTime() {
        return checkCostTime;
    }

    public void setCheckCostTime(Long checkCostTime) {
        this.checkCostTime = checkCostTime;
    }

    public Long getLevelOneAgentId() {
        return levelOneAgentId;
    }

    public void setLevelOneAgentId(Long levelOneAgentId) {
        this.levelOneAgentId = levelOneAgentId;
    }

    public String getLevelOneAgentName() {
        return levelOneAgentName;
    }

    public void setLevelOneAgentName(String levelOneAgentName) {
        this.levelOneAgentName = levelOneAgentName;
    }

    public Long getLandPageId() {
        return landPageId;
    }

    public void setLandPageId(Long landPageId) {
        this.landPageId = landPageId;
    }

    public Integer getUrlType() {
        return urlType;
    }

    public void setUrlType(Integer urlType) {
        this.urlType = urlType;
    }

    public String getImageUrl() {
        return imageUrl;
    }

    public void setImageUrl(String imageUrl) {
        this.imageUrl = imageUrl;
    }
}
